#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 concise
version:              0.1.0.1
visibility:           public
id:                   concise-0.1.0.1-EmAAj2LA0Qy8DB2fTDTsJ5
key:                  concise-0.1.0.1-EmAAj2LA0Qy8DB2fTDTsJ5
license:              BSD-3-Clause
copyright:            Copyright (C) 2016  Fraser Tweedale
maintainer:           frase@frase.id.au
author:               Fraser Tweedale
homepage:             https://github.com/frasertweedale/hs-concise
synopsis:             Utilities for Control.Lens.Cons
description:
    concise provides a handful of functions to extend what you can
    do with Control.Lens.Cons.

category:             Data, Lenses
abi:                  2b0c74d61792faa81fc315c9a71fca3a
exposed:              True
exposed-modules:      Control.Lens.Cons.Extras
import-dirs:          /usr/lib/ghc-9.6.6/site-local/concise-0.1.0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/concise-0.1.0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/concise-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-concise
hs-libraries:         HSconcise-0.1.0.1-EmAAj2LA0Qy8DB2fTDTsJ5
depends:
    base-4.18.2.1 bytestring-0.11.5.3 lens-5.3.4-F5uuXLon4Rz4s5xVUAhmEn
    text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-concise/html/concise.haddock
haddock-html:         /usr/share/doc/haskell-concise/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

